@@ -602,7 +602,10 @@ pub(crate) fn resolve_identifier<I: Interrupt>(
 		"sample" | "roll" => Value::BuiltInFunction(BuiltInFunction::Sample),
 		"sqrt" => evaluate_to_value("x: x^(1/2)", scope, attrs, context, int)?,
 		"cbrt" => evaluate_to_value("x: x^(1/3)", scope, attrs, context, int)?,
+		"real" | "re" | "Re" => Value::BuiltInFunction(BuiltInFunction::Real),
+		"imag" | "im" | "Im" => Value::BuiltInFunction(BuiltInFunction::Imag),
 		"conjugate" => Value::BuiltInFunction(BuiltInFunction::Conjugate),
+		"arg" => Value::BuiltInFunction(BuiltInFunction::Arg),
 		"abs" => Value::BuiltInFunction(BuiltInFunction::Abs),
 		"sin" => Value::BuiltInFunction(BuiltInFunction::Sin),
 		"cos" => Value::BuiltInFunction(BuiltInFunction::Cos),
