@@ -405,7 +405,7 @@ impl Value {
 	pub(crate) fn abs<I: Interrupt>(self, int: &I) -> Result<Self, FendError> {
 		let value = self.value.one_point()?.abs(int)?;
 		Ok(Self {
-			value: value.value.into(),
+			value: Complex::from(value.value).into(),
 			unit: self.unit,
 			exact: self.exact && value.exact,
 			base: self.base,
@@ -528,6 +528,28 @@ impl Value {
 		}
 	}
 
+	pub(crate) fn real(self) -> Result<Self, FendError> {
+		Ok(Self {
+			value: Complex::from(self.value.one_point()?.real()).into(),
+			..self
+		})
+	}
+
+	pub(crate) fn imag(self) -> Result<Self, FendError> {
+		Ok(Self {
+			value: Complex::from(self.value.one_point()?.imag()).into(),
+			..self
+		})
+	}
+
+	pub(crate) fn arg<I: Interrupt>(self, int: &I) -> Result<Self, FendError> {
+		self.apply_fn_exact(
+			|c, int| c.arg(int).map(|c| c.apply(Complex::from)),
+			false,
+			int,
+		)
+	}
+
 	pub(crate) fn conjugate(self) -> Result<Self, FendError> {
 		Ok(Self {
 			value: self.value.one_point()?.conjugate().into(),
@@ -627,7 +649,7 @@ impl Value {
 	}
 
 	pub(crate) fn ln<I: Interrupt>(self, int: &I) -> Result<Self, FendError> {
-		self.apply_fn(Complex::ln, true, int)
+		self.apply_fn_exact(Complex::ln, true, int)
 	}
 
 	pub(crate) fn log2<I: Interrupt>(self, int: &I) -> Result<Self, FendError> {
@@ -1186,7 +1208,7 @@ mod tests {
 	use crate::interrupt::Never;
 
 	fn to_string(n: &Value) -> String {
-		let int = &crate::interrupt::Never::default();
+		let int = &crate::interrupt::Never;
 		n.format(&crate::Context::new(), int).unwrap().to_string()
 	}
 
@@ -1198,13 +1220,13 @@ mod tests {
 		let kg = NamedUnit::new("k".into(), "g".into(), "g".into(), hashmap, 1);
 		let one_kg = Value::new(1, vec![UnitExponent::new(kg.clone(), 1)]);
 		let two_kg = Value::new(2, vec![UnitExponent::new(kg, 1)]);
-		let sum = one_kg.add(two_kg, &Never::default()).unwrap();
+		let sum = one_kg.add(two_kg, &Never).unwrap();
 		assert_eq!(to_string(&sum), "3 kg");
 	}
 
 	#[test]
 	fn test_basic_kg_and_g() {
-		let int = &Never::default();
+		let int = &Never;
 		let base_kg = BaseUnit::new("kilogram".into());
 		let mut hashmap = HashMap::new();
 		hashmap.insert(base_kg, 1.into());
