@@ -456,8 +456,8 @@ const COMMON_PHYSICAL_UNITS: &[UnitTuple] = &[
 	("light_minute", "light_minutes", "c minute", ""),
 	("light_hour", "light_hours", "c hour", ""),
 	("light_day", "light_days", "c day", ""),
-	("parsec", "parsecs", "au / tan(arcsec)", ""),
-	("pc", "", "parsec", ""),
+	("parsec", "parsecs", "l@au / tan(arcsec)", ""),
+	("pc", "", "s@parsec", ""),
 	(
 		"astronomical_unit",
 		"astronomical_units",
